@@ -1,38 +1,80 @@
-"""Contains the base/abstract classes that wraps the connection/querying logic of various databases.
+"""Contains the base classes that wraps the connection/querying logic of
+various databases.
 
 See documentation in database.py
 """
-from abc import ABCMeta, abstractmethod
+from abc import ABC, abstractmethod
+from typing import TypeVar
+import configparser
 import time
 import pandas as pd
 from helpsk.utility import suppress_stdout, suppress_warnings
 
 
-class Configuration(metaclass=ABCMeta):
-    """A basic configuration object will product a dictionary representing the keyword parameters that can
-    be passed to a Database object.
-    """
-    @abstractmethod
-    def get_dictionary(self) -> dict:
-        """
-        Returns:
-             a dictionary to be passed to the Database object
-        """
+ConnectionObject = TypeVar('ConnectionObject')
 
 
-class Database(metaclass=ABCMeta):
+class Database(ABC):
     """Base class that wraps the connection/querying logic of various databases.
     """
     def __init__(self, **kwargs):
-        self.connection_object = None
+        """
+        **kwargs should contain the names of the underlying connection object and corresponding
+        values.
+
+        For example:
+            - For Redshift, typical keyword arguments might be:
+                - `dbname`, `password`, `database`, `port`, `host`
+            - For Snowflake, typical keyword arguments might be:
+                - 'user', 'account', 'authenticator', 'warehouse', 'database', 'autocommit'
+        """
+        self._kwargs = kwargs
+        self.connection_object: ConnectionObject = None
 
     @classmethod
-    def from_config(cls, config: Configuration):
-        """Takes a Configuration object that contains the connection details to the database.
+    def from_config(cls, config_path: str, config_key: str) -> 'Database':
         """
-        return cls(**config.get_dictionary())
+        Passes key/value pairs found in configuration file into underlying connection. Keys must
+        match corresponding connection string or connection method arguments.
 
-    def is_connected(self):
+        For example:
+            - For Redshift, typical keys might be:
+                - `dbname`, `password`, `database`, `port`, `host`
+
+            ```
+            [redshift]
+            user=my_username
+            password=my-password-123
+            dbname=the_database
+            host=host.address.redshift.amazonaws.com
+            port=1234
+            ```
+
+            - For Snowflake, typical keys might be:
+                - 'user', 'account', 'authenticator', 'warehouse', 'database', 'autocommit'
+
+            ```
+            [snowflake]
+            user=my.email@address.com
+            account=account.id
+            authenticator=externalbrowser
+            warehouse=WAREHOUSE_NAME
+            database=DATABASE_NAME
+            ```
+
+        Args:
+            config_path:
+                path to the configuration file containing key/value pairs.
+            config_key:
+                name of the configuration key in configuration file
+                e.g. `[redshift]`
+        """
+        config = configparser.ConfigParser()
+        config.read(config_path)
+        config_dict = dict(config[config_key].items())
+        return cls(**config_dict)
+
+    def is_connected(self) -> bool:
         """
         Returns:
             True if the database is connected, otherwise False
@@ -40,20 +82,22 @@ class Database(metaclass=ABCMeta):
         return self.connection_object is not None
 
     @abstractmethod
-    def _open_connection_object(self) -> object:
-        """Child classes will implement the logic to connect to the database and return the connection object.
+    def _open_connection_object(self) -> ConnectionObject:
+        """Child classes will implement the logic to connect to the database and return the
+        connection object.
 
         The returning value will be stored in self.connection_object
 
         Returns:
-            the connection object (usually returned from the underlying `connect()` method. For example, the
-            returning value from `snowflake.connection.connect()`
+            the connection object (usually returned from the underlying `connect()` method.
+            For example, the returning value from `snowflake.connection.connect()`
         """
 
     @abstractmethod
     def _close_connection_object(self):
-        """Child classes will implement the logic to close the connection to the database, typically by
-        calling `close()` on the connection object returned from _open_connection_object.
+        """Child classes will implement the logic to close the connection to the database,
+        typically by calling `close()` on the connection object returned from
+        _open_connection_object.
 
         For example:
             self.connection_object.close()
@@ -162,7 +206,7 @@ class Database(metaclass=ABCMeta):
                        dataframe: pd.DataFrame,
                        table: str,
                        create_table: bool = False,
-                       overwrite: bool = True,
+                       overwrite: bool = False,
                        schema: str = None,
                        database: str = None):
         """
